window.Gleam.initSearch([{"doc":"gleastsq","title":"gleastsq","content":"# gleastsq\n\n[![Package Version](https://img.shields.io/hexpm/v/gleastsq)](https://hex.pm/packages/gleastsq)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleastsq/)\n\nA curve fitting library for Gleam. This library uses the [Nx](https://hexdocs.pm/nx/Nx.html) library from Elixir to perform matrix operations.\n\n## Levemberg-Marquardt vs Leasts Squares for curve fitting\n\nThe library provides two functions for curve fitting: `least_squares` and `levemberg_marquardt`.\n\n### Least Squares\n\nThe &#39;least_squares&#39; function is generally simpler and faster but may not converge for some functions, specially for non-linear functions.\nIt is generally recommended for simpler models where the relationship between the parameters and the function is linear.\n\n### Levenberg-Marquardt\n\nThe &#39;levemberg_marquardt&#39; function is more robust but may be slower due to the extra calculations.\nIt is generally recommended for non-linear functions where the relationship between the parameters and the function is non-linear.\n\n```sh\ngleam add gleastsq\n```\n\n```gleam\nimport gleam/option.{None}\nimport gleam/list\nimport gleam/io\nimport gleastsq\n\nfn parabola(x: Float, params: List(Float)) -&gt; Float {\n  let assert [a, b, c] = params\n  a *. x *. x +. b *. x +. c\n}\n\npub fn main() {\n  let x = [0.0, 1.0, 2.0, 3.0, 4.0, 5.0]\n  let y = list.map(x, fn(x) { x *. x })\n  let initial_guess = [1.0, 1.0, 1.0]\n\n  let assert Ok(result) =\n    gleastsq.least_squares(\n      x,\n      y,\n      parabola,\n      initial_guess,\n      max_iterations: None,\n      epsilon: None,\n      tolerance: None,\n      lambda_reg: None,\n    )\n\n  io.debug(result) // [1.0, 0.0, 0.0] (within numerical error)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gleastsq&gt;.\n","url":"index.html"},{"doc":"gleastsq/errors","title":"FitErrors","content":"pub type FitErrors {\n  NonConverged\n  WrongParameters(String)\n  JacobianTaskError\n}\n\nNonConverged\n\n\nWrongParameters(String)\n\n\nJacobianTaskError\n\n\nSynonyms:\ngleastsq/errors.FitErrors\ngleastsq/errors FitErrors","url":"gleastsq/errors.html#FitErrors"},{"doc":"gleastsq/errors","title":"gleastsq/errors","content":"","url":"gleastsq/errors.html"},{"doc":"gleastsq/least_squares","title":"least_squares","content":"pub fn least_squares(\n  x: List(Float),\n  y: List(Float),\n  func: fn(Float, List(Float)) -&gt; Float,\n  initial_params: List(Float),\n  max_iterations iterations: Option(Int),\n  epsilon epsilon: Option(Float),\n  tolerance tolerance: Option(Float),\n  lambda_reg lambda_reg: Option(Float),\n) -&gt; Result(List(Float), FitErrors)\n The `least_squares` function performs a basic least squares optimization algorithm.\n It is used to find the best-fit parameters for a given model function to a set of data points.\n This function takes as input the data points, the model function, and several optional parameters to control the optimization process.\n\n # Parameters\n - `x` (List(Float))\n     A list of x-values of the data points.\n - `y` (List(Float))\n     A list of y-values of the data points.\n - `func` (fn(Float, List(Float)) -&gt; Float)\n     The model function that takes an x-value and a list of parameters, and returns the corresponding y-value.\n - `initial_params` (List(Float))\n     A list of initial guesses for the parameters of the model function.\n - `iterations` (Option(Int))\n     The maximum number of iterations to perform.\n     Default is 100.\n - `epsilon` (Option(Float))\n     A small value to change x when calculating the derivatives for the function.\n     Default is 0.0001.\n - `tolerance` (Option(Float))\n     The convergence tolerance.\n     Default is 0.0001.\n - `lambda_reg` (Option(Float))\n     The regularization parameter.\n     Default is 0.0001.\nSynonyms:\ngleastsq/least_squares.least_squares\ngleastsq/least_squares least_squares","url":"gleastsq/least_squares.html#least_squares"},{"doc":"gleastsq/least_squares","title":"gleastsq/least_squares","content":"","url":"gleastsq/least_squares.html"},{"doc":"gleastsq/levemberg_marquardt","title":"levenberg_marquardt","content":"pub fn levenberg_marquardt(\n  x: List(Float),\n  y: List(Float),\n  func: fn(Float, List(Float)) -&gt; Float,\n  initial_params: List(Float),\n  max_iterations iterations: Option(Int),\n  epsilon epsilon: Option(Float),\n  tolerance tolerance: Option(Float),\n  damping damping: Option(Float),\n  damping_increase damping_increase: Option(Float),\n  damping_decrease damping_decrease: Option(Float),\n) -&gt; Result(List(Float), FitErrors)\n The `levenberg_marquardt` function performs the Levenberg-Marquardt optimization algorithm.\n It is used to solve non-linear least squares problems. This function takes as input the data points,\n the model function, and several optional parameters to control the optimization process.\n\n # Parameters\n - `x` (List(Float))\n     A list of x-values of the data points.\n - `y` (List(Float))\n     A list of y-values of the data points.\n - `func` (fn(Float, List(Float)) -&gt; Float)\n     The model function that takes an x-value and a list of parameters, and returns the corresponding y-value.\n - `initial_params` (List(Float))\n     A list of initial guesses for the parameters of the model function.\n - `iterations` (Option(Int))\n     The maximum number of iterations to perform.\n     Default is 100.\n - `epsilon` (Option(Float))\n     A small value to change x when calculating the derivatives for the function.\n     Default is 0.0001.\n - `tolerance` (Option(Float))\n     The convergence tolerance.\n     Default is 0.0001.\n - `damping` (Option(Float))\n     The initial value of the damping parameter.\n     Default is 0.0001.\n - `damping_increase` (Option(Float))\n     The factor by which the damping parameter is increased when a step fails.\n     Default is 10.0.\n - `damping_decrease` (Option(Float)):\n     The factor by which the damping parameter is decreased when a step succeeds.\n     Default is 0.1.\nSynonyms:\ngleastsq/levemberg_marquardt.levenberg_marquardt\ngleastsq/levemberg_marquardt levenberg_marquardt","url":"gleastsq/levemberg_marquardt.html#levenberg_marquardt"},{"doc":"gleastsq/levemberg_marquardt","title":"gleastsq/levemberg_marquardt","content":"","url":"gleastsq/levemberg_marquardt.html"},{"doc":"gleastsq","title":"least_squares","content":"pub fn least_squares(\n  x: List(Float),\n  y: List(Float),\n  func: fn(Float, List(Float)) -&gt; Float,\n  initial_params: List(Float),\n  max_iterations iterations: Option(Int),\n  epsilon epsilon: Option(Float),\n  tolerance tolerance: Option(Float),\n  lambda_reg lambda_reg: Option(Float),\n) -&gt; Result(List(Float), FitErrors)\n The `least_squares` function performs a basic least squares optimization algorithm.\n It is used to find the best-fit parameters for a given model function to a set of data points.\n This function takes as input the data points, the model function, and several optional parameters to control the optimization process.\n\n # Parameters\n - `x` (List(Float))\n     A list of x-values of the data points.\n - `y` (List(Float))\n     A list of y-values of the data points.\n - `func` (fn(Float, List(Float)) -&gt; Float)\n     The model function that takes an x-value and a list of parameters, and returns the corresponding y-value.\n - `initial_params` (List(Float))\n     A list of initial guesses for the parameters of the model function.\n - `iterations` (Option(Int))\n     The maximum number of iterations to perform.\n     Default is 100.\n - `epsilon` (Option(Float))\n     A small value to change x when calculating the derivatives for the function.\n     Default is 0.0001.\n - `tolerance` (Option(Float))\n     The convergence tolerance.\n     Default is 0.0001.\n - `lambda_reg` (Option(Float))\n     The regularization parameter.\n     Default is 0.0001.\nSynonyms:\ngleastsq.least_squares\ngleastsq least_squares","url":"gleastsq.html#least_squares"},{"doc":"gleastsq","title":"levenberg_marquardt","content":"pub fn levenberg_marquardt(\n  x: List(Float),\n  y: List(Float),\n  func: fn(Float, List(Float)) -&gt; Float,\n  initial_params: List(Float),\n  max_iterations iterations: Option(Int),\n  epsilon epsilon: Option(Float),\n  tolerance tolerance: Option(Float),\n  damping damping: Option(Float),\n  damping_increase damping_increase: Option(Float),\n  damping_decrease damping_decrease: Option(Float),\n) -&gt; Result(List(Float), FitErrors)\n The `levenberg_marquardt` function performs the Levenberg-Marquardt optimization algorithm.\n It is used to solve non-linear least squares problems. This function takes as input the data points,\n the model function, and several optional parameters to control the optimization process.\n\n # Parameters\n - `x` (List(Float))\n     A list of x-values of the data points.\n - `y` (List(Float))\n     A list of y-values of the data points.\n - `func` (fn(Float, List(Float)) -&gt; Float)\n     The model function that takes an x-value and a list of parameters, and returns the corresponding y-value.\n - `initial_params` (List(Float))\n     A list of initial guesses for the parameters of the model function.\n - `iterations` (Option(Int))\n     The maximum number of iterations to perform.\n     Default is 100.\n - `epsilon` (Option(Float))\n     A small value to change x when calculating the derivatives for the function.\n     Default is 0.0001.\n - `tolerance` (Option(Float))\n     The convergence tolerance.\n     Default is 0.0001.\n - `damping` (Option(Float))\n     The initial value of the damping parameter.\n     Default is 0.0001.\n - `damping_increase` (Option(Float))\n     The factor by which the damping parameter is increased when a step fails.\n     Default is 10.0.\n - `damping_decrease` (Option(Float)):\n     The factor by which the damping parameter is decreased when a step succeeds.\n     Default is 0.1.\nSynonyms:\ngleastsq.levenberg_marquardt\ngleastsq levenberg_marquardt","url":"gleastsq.html#levenberg_marquardt"},{"doc":"gleastsq","title":"gleastsq","content":"","url":"gleastsq.html"}]);